@@ -1,7 +1,7 @@
 package Task::DualLived;
 
 use 5.005;
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 1;
 __END__
@@ -29,11 +29,11 @@ Task::DualLived - Perl extension for updating dual-lived modules
 
 =head1 AUTHOR
 
-  Kevin W. Henwood, <Khen1950fx@aol.com>
+  Kevin W. Henwood, <Khen1950fx@yahoo.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2012 by Kevin W. Henwood
+Copyright (C) 2012-2013 by Kevin W. Henwood
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.005 or,
